@@ -128,7 +128,7 @@ public class AggregateTransformer {
      */
     private static volatile int counter = 0;
 
-    /** the format to use for the report. Must be <tt>FRAMES</tt> or <tt>NOFRAMES</tt> */
+    /** the format to use for the report. Must be <code>FRAMES</code> or <code>NOFRAMES</code> */
     protected String format = FRAMES;
 
     // CheckStyle:VisibilityModifier ON
@@ -154,7 +154,7 @@ public class AggregateTransformer {
 
     /**
      * sets the format.
-     * @param format  Must be <tt>FRAMES</tt> or <tt>NOFRAMES</tt>
+     * @param format  Must be <code>FRAMES</code> or <code>NOFRAMES</code>
      */
     public void setFormat(Format format) {
         this.format = format.getValue();
@@ -297,10 +297,7 @@ public class AggregateTransformer {
      * @return stylesheet as a resource
      */
     protected Resource getStylesheet() {
-        String xslname = "junit-frames.xsl";
-        if (NOFRAMES.equals(format)) {
-            xslname = "junit-noframes.xsl";
-        }
+        final String xslname = getXslName();
         if (styleDir == null) {
             // If style dir is not specified we have to retrieve
             // the stylesheet from the classloader
@@ -313,6 +310,32 @@ public class AggregateTransformer {
         return new FileResource(new File(styleDir, xslname));
     }
 
+    /**
+     * Gets the filename of the XSL stylesheet
+     *
+     * Will provide Xalan or Saxon specific
+     * stylesheets.
+     *
+     * @return The filename of the stylesheet
+     */
+    private String getXslName() {
+        final String suffix;
+
+        final String xsltFactoryName = xsltFactory == null ? null :  xsltFactory.getName();
+        if ("net.sf.saxon.TransformerFactoryImpl".equals(xsltFactoryName)) {
+            suffix = "-saxon.xsl";
+        } else {
+            suffix = ".xsl";
+        }
+        final String xslname;
+        if (NOFRAMES.equals(format)) {
+            xslname = "junit-noframes" + suffix;
+        } else {
+            xslname = "junit-frames" + suffix;
+        }
+        return xslname;
+    }
+
     /** check for invalid options
      * @throws BuildException if something goes wrong.
      */
@@ -335,10 +358,7 @@ public class AggregateTransformer {
      * not exist.
      */
     protected String getStylesheetSystemId() throws IOException {
-        String xslname = "junit-frames.xsl";
-        if (NOFRAMES.equals(format)) {
-            xslname = "junit-noframes.xsl";
-        }
+        final String xslname = getXslName();
         if (styleDir == null) {
             URL url = getClass().getResource("xsl/" + xslname);
             if (url == null) {
